@@ -1,6 +1,10 @@
-package RT::TicketCustomFieldValue;
+use RT::ObjectCustomFieldValue ();
+package RT::ObjectCustomFieldValue;
 
 use strict;
+use warnings;
+use warnings FATAL => 'redefine';
+
 use RTx::Shredder::Constants;
 use RTx::Shredder::Exceptions;
 use RTx::Shredder::Dependencies;
